<a id="mypy-boto3-fsx"></a>

# mypy-boto3-fsx

[![PyPI - types-aiobotocore-fsx](https://img.shields.io/pypi/v/types-aiobotocore-fsx.svg?color=blue)](https://pypi.org/project/types-aiobotocore-fsx)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-fsx.svg?color=blue)](https://pypi.org/project/types-aiobotocore-fsx)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-fsx?color=blue)](https://pypistats.org/packages/types-aiobotocore-fsx)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.FSx 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fsx.html#FSx)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-fsx docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_fsx/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-fsx](#mypy-boto3-fsx)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `FSx`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `FSx` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[fsx]'

# Lite version does not provide session.create_client overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[fsx]'

# standalone installation
python -m pip install types-aiobotocore-fsx
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[fsx]` in your environment:
  `python -m pip install 'types-aiobotocore[fsx]'`

Both type checking and auto-complete should work for `FSx` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[fsx]` in your environment:
  `python -m pip install 'types-aiobotocore[fsx]'`

Both type checking and auto-complete should work for `FSx` service. No explicit
type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[fsx]` in your environment:
  `python -m pip install 'types-aiobotocore[fsx]'`
- Run `mypy` as usual

Type checking should work for `FSx` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[fsx]` in your environment:
  `python -m pip install 'types-aiobotocore[fsx]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `FSx` service. No explicit type annotations
required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`FSxClient` provides annotations for `session.create_client("fsx")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_fsx import FSxClient

session = get_session()
async with session.create_client("fsx") as client:
    client: FSxClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_fsx.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_fsx import FSxClient
from types_aiobotocore_fsx.paginator import (
    DescribeBackupsPaginator,
    DescribeFileSystemsPaginator,
    ListTagsForResourcePaginator,
)

session = get_session()
async with session.create_client("fsx") as client:
    client: FSxClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_backups_paginator: DescribeBackupsPaginator = client.get_paginator("describe_backups")
        describe_file_systems_paginator: DescribeFileSystemsPaginator = client.get_paginator("describe_file_systems")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
    ```







### Literals

`types_aiobotocore_fsx.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_fsx.literals import (
    AdministrativeActionTypeType,
    AliasLifecycleType,
    AutoImportPolicyTypeType,
    BackupLifecycleType,
    BackupTypeType,
    DataCompressionTypeType,
    DataRepositoryLifecycleType,
    DataRepositoryTaskFilterNameType,
    DataRepositoryTaskLifecycleType,
    DataRepositoryTaskTypeType,
    DeleteOpenZFSVolumeOptionType,
    DescribeBackupsPaginatorName,
    DescribeFileSystemsPaginatorName,
    DiskIopsConfigurationModeType,
    DriveCacheTypeType,
    EventTypeType,
    FileSystemLifecycleType,
    FileSystemMaintenanceOperationType,
    FileSystemTypeType,
    FilterNameType,
    FlexCacheEndpointTypeType,
    ListTagsForResourcePaginatorName,
    LustreAccessAuditLogLevelType,
    LustreDeploymentTypeType,
    OntapDeploymentTypeType,
    OntapVolumeTypeType,
    OpenZFSCopyStrategyType,
    OpenZFSDataCompressionTypeType,
    OpenZFSDeploymentTypeType,
    OpenZFSQuotaTypeType,
    ReportFormatType,
    ReportScopeType,
    ResourceTypeType,
    RestoreOpenZFSVolumeOptionType,
    SecurityStyleType,
    SnapshotFilterNameType,
    SnapshotLifecycleType,
    StatusType,
    StorageTypeType,
    StorageVirtualMachineFilterNameType,
    StorageVirtualMachineLifecycleType,
    StorageVirtualMachineRootVolumeSecurityStyleType,
    StorageVirtualMachineSubtypeType,
    TieringPolicyNameType,
    VolumeFilterNameType,
    VolumeLifecycleType,
    VolumeTypeType,
    WindowsAccessAuditLogLevelType,
    WindowsDeploymentTypeType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AdministrativeActionTypeType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_fsx.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_fsx.type_defs import (
    ActiveDirectoryBackupAttributesTypeDef,
    AdministrativeActionFailureDetailsTypeDef,
    AdministrativeActionTypeDef,
    AliasTypeDef,
    AssociateFileSystemAliasesRequestRequestTypeDef,
    AssociateFileSystemAliasesResponseTypeDef,
    AutoExportPolicyTypeDef,
    AutoImportPolicyTypeDef,
    BackupFailureDetailsTypeDef,
    BackupTypeDef,
    CancelDataRepositoryTaskRequestRequestTypeDef,
    CancelDataRepositoryTaskResponseTypeDef,
    CompletionReportTypeDef,
    CopyBackupRequestRequestTypeDef,
    CopyBackupResponseTypeDef,
    CreateBackupRequestRequestTypeDef,
    CreateBackupResponseTypeDef,
    CreateDataRepositoryAssociationRequestRequestTypeDef,
    CreateDataRepositoryAssociationResponseTypeDef,
    CreateDataRepositoryTaskRequestRequestTypeDef,
    CreateDataRepositoryTaskResponseTypeDef,
    CreateFileSystemFromBackupRequestRequestTypeDef,
    CreateFileSystemFromBackupResponseTypeDef,
    CreateFileSystemLustreConfigurationTypeDef,
    CreateFileSystemOntapConfigurationTypeDef,
    CreateFileSystemOpenZFSConfigurationTypeDef,
    CreateFileSystemRequestRequestTypeDef,
    CreateFileSystemResponseTypeDef,
    CreateFileSystemWindowsConfigurationTypeDef,
    CreateOntapVolumeConfigurationTypeDef,
    CreateOpenZFSOriginSnapshotConfigurationTypeDef,
    CreateOpenZFSVolumeConfigurationTypeDef,
    CreateSnapshotRequestRequestTypeDef,
    CreateSnapshotResponseTypeDef,
    CreateStorageVirtualMachineRequestRequestTypeDef,
    CreateStorageVirtualMachineResponseTypeDef,
    CreateSvmActiveDirectoryConfigurationTypeDef,
    CreateVolumeFromBackupRequestRequestTypeDef,
    CreateVolumeFromBackupResponseTypeDef,
    CreateVolumeRequestRequestTypeDef,
    CreateVolumeResponseTypeDef,
    DataRepositoryAssociationTypeDef,
    DataRepositoryConfigurationTypeDef,
    DataRepositoryFailureDetailsTypeDef,
    DataRepositoryTaskFailureDetailsTypeDef,
    DataRepositoryTaskFilterTypeDef,
    DataRepositoryTaskStatusTypeDef,
    DataRepositoryTaskTypeDef,
    DeleteBackupRequestRequestTypeDef,
    DeleteBackupResponseTypeDef,
    DeleteDataRepositoryAssociationRequestRequestTypeDef,
    DeleteDataRepositoryAssociationResponseTypeDef,
    DeleteFileSystemLustreConfigurationTypeDef,
    DeleteFileSystemLustreResponseTypeDef,
    DeleteFileSystemOpenZFSConfigurationTypeDef,
    DeleteFileSystemOpenZFSResponseTypeDef,
    DeleteFileSystemRequestRequestTypeDef,
    DeleteFileSystemResponseTypeDef,
    DeleteFileSystemWindowsConfigurationTypeDef,
    DeleteFileSystemWindowsResponseTypeDef,
    DeleteSnapshotRequestRequestTypeDef,
    DeleteSnapshotResponseTypeDef,
    DeleteStorageVirtualMachineRequestRequestTypeDef,
    DeleteStorageVirtualMachineResponseTypeDef,
    DeleteVolumeOntapConfigurationTypeDef,
    DeleteVolumeOntapResponseTypeDef,
    DeleteVolumeOpenZFSConfigurationTypeDef,
    DeleteVolumeRequestRequestTypeDef,
    DeleteVolumeResponseTypeDef,
    DescribeBackupsRequestRequestTypeDef,
    DescribeBackupsResponseTypeDef,
    DescribeDataRepositoryAssociationsRequestRequestTypeDef,
    DescribeDataRepositoryAssociationsResponseTypeDef,
    DescribeDataRepositoryTasksRequestRequestTypeDef,
    DescribeDataRepositoryTasksResponseTypeDef,
    DescribeFileSystemAliasesRequestRequestTypeDef,
    DescribeFileSystemAliasesResponseTypeDef,
    DescribeFileSystemsRequestRequestTypeDef,
    DescribeFileSystemsResponseTypeDef,
    DescribeSnapshotsRequestRequestTypeDef,
    DescribeSnapshotsResponseTypeDef,
    DescribeStorageVirtualMachinesRequestRequestTypeDef,
    DescribeStorageVirtualMachinesResponseTypeDef,
    DescribeVolumesRequestRequestTypeDef,
    DescribeVolumesResponseTypeDef,
    DisassociateFileSystemAliasesRequestRequestTypeDef,
    DisassociateFileSystemAliasesResponseTypeDef,
    DiskIopsConfigurationTypeDef,
    FileSystemEndpointTypeDef,
    FileSystemEndpointsTypeDef,
    FileSystemFailureDetailsTypeDef,
    FileSystemTypeDef,
    FilterTypeDef,
    LifecycleTransitionReasonTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    LustreFileSystemConfigurationTypeDef,
    LustreLogConfigurationTypeDef,
    LustreLogCreateConfigurationTypeDef,
    OntapFileSystemConfigurationTypeDef,
    OntapVolumeConfigurationTypeDef,
    OpenZFSClientConfigurationTypeDef,
    OpenZFSCreateRootVolumeConfigurationTypeDef,
    OpenZFSFileSystemConfigurationTypeDef,
    OpenZFSNfsExportTypeDef,
    OpenZFSOriginSnapshotConfigurationTypeDef,
    OpenZFSUserOrGroupQuotaTypeDef,
    OpenZFSVolumeConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ReleaseFileSystemNfsV3LocksRequestRequestTypeDef,
    ReleaseFileSystemNfsV3LocksResponseTypeDef,
    ResponseMetadataTypeDef,
    RestoreVolumeFromSnapshotRequestRequestTypeDef,
    RestoreVolumeFromSnapshotResponseTypeDef,
    S3DataRepositoryConfigurationTypeDef,
    SelfManagedActiveDirectoryAttributesTypeDef,
    SelfManagedActiveDirectoryConfigurationTypeDef,
    SelfManagedActiveDirectoryConfigurationUpdatesTypeDef,
    SnapshotFilterTypeDef,
    SnapshotTypeDef,
    StorageVirtualMachineFilterTypeDef,
    StorageVirtualMachineTypeDef,
    SvmActiveDirectoryConfigurationTypeDef,
    SvmEndpointTypeDef,
    SvmEndpointsTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TieringPolicyTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDataRepositoryAssociationRequestRequestTypeDef,
    UpdateDataRepositoryAssociationResponseTypeDef,
    UpdateFileSystemLustreConfigurationTypeDef,
    UpdateFileSystemOntapConfigurationTypeDef,
    UpdateFileSystemOpenZFSConfigurationTypeDef,
    UpdateFileSystemRequestRequestTypeDef,
    UpdateFileSystemResponseTypeDef,
    UpdateFileSystemWindowsConfigurationTypeDef,
    UpdateOntapVolumeConfigurationTypeDef,
    UpdateOpenZFSVolumeConfigurationTypeDef,
    UpdateSnapshotRequestRequestTypeDef,
    UpdateSnapshotResponseTypeDef,
    UpdateStorageVirtualMachineRequestRequestTypeDef,
    UpdateStorageVirtualMachineResponseTypeDef,
    UpdateSvmActiveDirectoryConfigurationTypeDef,
    UpdateVolumeRequestRequestTypeDef,
    UpdateVolumeResponseTypeDef,
    VolumeFilterTypeDef,
    VolumeTypeDef,
    WindowsAuditLogConfigurationTypeDef,
    WindowsAuditLogCreateConfigurationTypeDef,
    WindowsFileSystemConfigurationTypeDef,
)

def get_structure() -> ActiveDirectoryBackupAttributesTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-fsx` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-fsx docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_fsx/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
